@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """Make and handle requests."""
 
 import json
@@ -17,9 +15,8 @@ def get(api_path):
             return json.loads(response.text)
         except ValueError:
             # handle the list of dictionaries returned from the pdns endpoints
-            return [json.loads(entry) for entry in response.text.split("\r\n") if entry is not '']
+            return [json.loads(entry) for entry in response.text.split("\r\n") if entry != '']
     else:
         # print information about the error
-        print("{} error retrieving {}: {}".format(response.status_code,
-                                                  api_path, response.text))
+        print("{} error retrieving {}: {}".format(response.status_code, api_path, response.text))
         return None
